@@ -253,7 +253,7 @@ class DateService(object):
     def extractDay(self, input):
         """Returns the first time-related date found in the input string,
         or None if not found."""
-        day = self.extractDay(input)
+        day = self.extractDays(input)
         if day:
             return day[0]
         return None
