@@ -5,11 +5,20 @@ from semantic.dates import DateService
 
 class TestDate(unittest.TestCase):
 
-    def compareDate(self, input, target):
+    def compareDay(self, input, target):
+        service = DateService()
+        result = service.extractDay(input)
+        self.assertEqual(result.month, target.month)
+        self.assertEqual(result.day, target.day)
+
+    def compareDate(self, input, target, TIME=False):
         service = DateService()
         result = service.extractDate(input)
         self.assertEqual(result.month, target.month)
         self.assertEqual(result.day, target.day)
+        if TIME:
+            self.assertEqual(result.hour, target.hour)
+            self.assertEqual(result.minute, target.minute)
 
     def compareTime(self, input, target):
         service = DateService()
@@ -17,12 +26,22 @@ class TestDate(unittest.TestCase):
         self.assertEqual(result.hour, target.hour)
         self.assertEqual(result.minute, target.minute)
 
-    def compareDates(self, input, targets):
+    def compareDays(self, input, targets):
+        service = DateService()
+        results = service.extractDays(input)
+        for (result, target) in zip(results, targets):
+            self.assertEqual(result.month, target.month)
+            self.assertEqual(result.day, target.day)
+
+    def compareDates(self, input, targets, TIME=False):
         service = DateService()
         results = service.extractDates(input)
         for (result, target) in zip(results, targets):
             self.assertEqual(result.month, target.month)
             self.assertEqual(result.day, target.day)
+            if TIME:
+                self.assertEqual(result.hour, target.hour)
+                self.assertEqual(result.minute, target.minute)
 
     def compareTimes(self, input, targets):
         service = DateService()
@@ -137,8 +156,16 @@ class TestDate(unittest.TestCase):
         input = "From March 13 at 12:30pm to September 2 at 11:15am"
         targets = [datetime.datetime(2014, 3, 13, 12, 30),
                    datetime.datetime(2014, 9, 2, 11, 15)]
-        self.compareDates(input, targets)
-        self.compareTimes(input, targets)
+        self.compareDates(input, targets, TIME=True)
+
+    #
+    # Single extractor tests
+    #
+    def testExtractDay(self):
+        input = "On March 13 at 12:30pm."
+        target = datetime.datetime(2014, 3, 13)
+        self.compareDay(input, target)
+
 
 if __name__ == "__main__":
     suite = unittest.TestLoader().loadTestsFromTestCase(TestDate)
